<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2019 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

/** @var Akeeba\TicketSystem\Site\View\Tickets\Html $this */
/** @var \Akeeba\TicketSystem\Site\Model\Tickets $ticket */

use Akeeba\TicketSystem\Admin\Helper\Format;
use Akeeba\TicketSystem\Admin\Helper\Html;

defined('_JEXEC') or die;

/**
 * This view template renders a single row (a single ticket) in a list of tickets.
 *
 * It is used when listing tickets in a category, tickets filed by a specific user (including My Tickets), tickets
 * belonging to the selected bucket and tickets assigned to the current user.
 *
 * Params incoming loadAnyTemplate:
 *
 * $ticket          Ticket to display
 * $showAssigned    Should I display the assigned user dropdown?
 * $showCategory    Should I display the category?
 * $showMy          Should I display the "my" icon?
 * $showStatus      Should I display the status?
 * $showStatusDD    Should I display the status dropdown?
 * $extraRowAttr    Additional attributes to attach to the table row
 * $extraLinkAttr   Additional attributes to attach to the ticket link
 */

if (!isset($showAgo)) $showAgo = 0;
if (!isset($showAssigned)) $showAssigned = 1;
if (!isset($showCategory)) $showCategory = 0;
if (!isset($showMy)) $showMy = 1;
if (!isset($showStatus)) $showStatus = 1;
if (!isset($showStatusDD)) $showStatusDD = 1;
if (!isset($extraRowAttr)) $extraRowAttr = '';
if (!isset($extraLinkAttr)) $extraLinkAttr = '';

$createdOn  = Format::date2($ticket->created_on, '', true);
$createdBy  = $this->getContainer()->platform->getUser($ticket->created_by)->username;
$lastOn     = $createdOn;
$lastBy     = $createdBy;
$modifiedOn = $this->getContainer()->platform->getDate($ticket->modified_on);

if ($modifiedOn->toUnix() > 90000)
{
	$lastOn     = $ticket->modified_on;
	$modifiedBy = $ticket->modified_by ? $ticket->modified_by : $ticket->created_by;
	$lastBy     = $this->getContainer()->platform->getUser($modifiedBy)->username;
}

$curUser     = $this->getContainer()->platform->getUser();
$mine        = $curUser->id == $ticket->created_by;
$icon        = $ticket->public ? 'akion-eye' : 'akion-eye-disabled';
$assigned_to = $ticket->assigned_to ? $ticket->getUser($ticket->assigned_to)->name : JText::_('COM_ATS_TICKETS_UNASSIGNED');
?>
<tr id="ats-ticket-{{{ (int) $ticket->ats_ticket_id }}}" {{ $extraRowAttr }}>
    @if($ticket->priority > 5)
        <td class="low-priority">
            <span class="akion-arrow-down-c hasTooltip" title="@lang('COM_ATS_LOW_PRIORITY')"></span>
        </td>
    @elseif (($ticket->priority > 0) && ($ticket->priority < 5))
        <td class="high-priority">
            <span class="akion-arrow-up-c hasTooltip" title="@lang('COM_ATS_HIGH_PRIORITY')"></span>
        </td>
    @else
        <td></td>
    @endif
    <td class="badges">

        @if($showMy && $mine)
            <span class="akion-person ats-my-ticket akeeba-label--grey hasTooltip"
                  title="@lang('COM_ATS_CREATED_BY_ME')"></span>
        @endif

        <span class="ats-visibility hasTooltip akeeba-label--{{ $ticket->public ? 'grey' : 'green' }}"
              title="@lang($ticket->public ? 'COM_ATS_NEWTICKET_LBL_PUBLIC' : 'COM_ATS_NEWTICKET_LBL_PRIVATE')">
            <span class="{{ $icon }}"></span>
        </span>

        @if($showAssigned && $this->isManager && ATS_PRO && ($ticket->timespent > 0))
            <span class="akeeba-label--teal hasTooltip time-spent"
                  title="@sprintf('COM_ATS_TICKET_LBL_HAVESPENTXMINUTESTICKET', $ticket->timespent)">
            {{{ $ticket->timespent }}}'
        </span>
        @endif
    </td>
    <td>
        <h3 class="akeeba-pull-left ats-ticket-title">
            @if ($showAgo)
                <span class="ats-opened-ago akeeba-label--orange small akeeba-pull-left">
                    {{{ Format::timeAgo($this->getContainer()->platform->getDate($lastOn)->toUnix()) }}}
                </span>
            @endif
            <a href="@route('index.php?option=com_ats&view=Ticket&id=' . $ticket->ats_ticket_id)" {{ $extraLinkAttr}} >
                &nbsp;#{{ $ticket->ats_ticket_id }}: {{{$ticket->title}}}
            </a>

            <span class="ats-clear"></span>
        </h3>

        <input type="hidden" class="ticket_id" value="{{{ $ticket->ats_ticket_id }}}" />

        <div class="akeeba-pull-right ticketstatus">
            @if ($this->isManager && $showStatusDD)
                {{ Html::createStatusDropdown($ticket->status) }}
            @elseif ($showStatus)
                <span class="ats-status {{ Html::getStatusClass($ticket->status) }}">
                    {{ Html::decodeStatus($ticket->status) }}
                </span>
            @endif
        </div>

        @if ($showAssigned && $this->isManager && ATS_PRO)
            <div class="akeeba-pull-right assignto">
                <span class="akeeba-pull-right">&nbsp;</span>
                {{ Html::buildManagerdd(null, $assigned_to, $ticket->catid) }}
            </div>
        @endif

        <div class="ats-clear"></div>

        @if ($showCategory)
            <div class="ats-latest-category">
                {{ Format::categoryName($ticket->catid) }}
            </div>
            <div class="ats-clear"></div>
        @endif

        <div>
			<span class="small akeeba-pull-right">
				@sprintf('COM_ATS_TICKETS_MSG_LASTPOST', $lastBy, Format::date2($lastOn, '', true))
			</span>
            <span class="small akeeba-pull-left">
				@sprintf('COM_ATS_TICKETS_MSG_CREATED', $createdOn, $createdBy)
			</span>
        </div>
    </td>
</tr>
